@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -61,8 +65,8 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "parser.y" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 1 "parser.y" /* yacc.c:337  */
 
 /*
  *
@@ -96,13 +100,16 @@ int yydebug=1;
 
 
 
-#line 100 "y.tab.c" /* yacc.c:339  */
-
+#line 104 "y.tab.c" /* yacc.c:337  */
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -251,10 +258,10 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
-#line 38 "parser.y" /* yacc.c:355  */
+#line 38 "parser.y" /* yacc.c:352  */
 
 	int32		ival;
 	char	   *str;
@@ -262,8 +269,10 @@ union YYSTYPE
 	AttElemList	*att_elem_list;
 	SlonDString *dstring;
 
-#line 266 "y.tab.c" /* yacc.c:355  */
+#line 273 "y.tab.c" /* yacc.c:352  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
@@ -275,9 +284,7 @@ int yyparse (void);
 
 #endif /* !YY_YY_Y_TAB_H_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 281 "y.tab.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -298,13 +305,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -316,7 +323,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -352,15 +359,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -368,7 +366,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -530,16 +528,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  296
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   314
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -904,22 +902,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -959,37 +957,37 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -1023,7 +1021,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -1034,7 +1032,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               );
       YYFPRINTF (stderr, "\n");
     }
@@ -1138,7 +1136,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -1156,7 +1157,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1234,10 +1235,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1249,6 +1250,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1260,9 +1262,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1388,23 +1391,31 @@ yyparse (void)
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1420,14 +1431,10 @@ yyparse (void)
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1443,22 +1450,22 @@ yyparse (void)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1467,11 +1474,11 @@ yyparse (void)
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1544,7 +1551,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1565,70 +1572,70 @@ yyreduce:
   switch (yyn)
     {
         case 18:
-#line 164 "parser.y" /* yacc.c:1646  */
+#line 164 "parser.y" /* yacc.c:1652  */
     {
 						if (archive_dir != NULL)
 							parse_error("duplicate archive dir specification");
 						else
 							archive_dir = strdup((yyvsp[-1].str));
 					}
-#line 1576 "y.tab.c" /* yacc.c:1646  */
+#line 1583 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 19:
-#line 173 "parser.y" /* yacc.c:1646  */
+#line 173 "parser.y" /* yacc.c:1652  */
     {
 						if (destination_dir != NULL)
 							parse_error("duplicate destination dir specification");
 						else
 							destination_dir = strdup((yyvsp[-1].str));
 					}
-#line 1587 "y.tab.c" /* yacc.c:1646  */
+#line 1594 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 20:
-#line 182 "parser.y" /* yacc.c:1646  */
+#line 182 "parser.y" /* yacc.c:1652  */
     {
 						if (destination_conninfo != NULL)
 							parse_error("duplicate destination database specification");
 						else
 							destination_conninfo = strdup((yyvsp[-1].str));
 					}
-#line 1598 "y.tab.c" /* yacc.c:1646  */
+#line 1605 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 21:
-#line 191 "parser.y" /* yacc.c:1646  */
+#line 191 "parser.y" /* yacc.c:1652  */
     {
 						if (logfile_path != NULL)
 							parse_error("duplicate logfile path specification");
 						else
 							logfile_path = strdup((yyvsp[-1].str));
 					}
-#line 1609 "y.tab.c" /* yacc.c:1646  */
+#line 1616 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 22:
-#line 200 "parser.y" /* yacc.c:1646  */
+#line 200 "parser.y" /* yacc.c:1652  */
     {
 						max_archives = (yyvsp[-1].ival);
 					}
-#line 1617 "y.tab.c" /* yacc.c:1646  */
+#line 1624 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 23:
-#line 206 "parser.y" /* yacc.c:1646  */
+#line 206 "parser.y" /* yacc.c:1652  */
     {
 						if (cluster_name != NULL)
 							parse_error("duplicate cluster name specification");
 						else
 							cluster_name = strdup((yyvsp[-1].str));
 					}
-#line 1628 "y.tab.c" /* yacc.c:1646  */
+#line 1635 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 24:
-#line 215 "parser.y" /* yacc.c:1646  */
+#line 215 "parser.y" /* yacc.c:1652  */
     {
 						RenameObject *new;
 
@@ -1639,11 +1646,11 @@ yyreduce:
 
 						config_add_rename(new);
 					}
-#line 1643 "y.tab.c" /* yacc.c:1646  */
+#line 1650 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 25:
-#line 226 "parser.y" /* yacc.c:1646  */
+#line 226 "parser.y" /* yacc.c:1652  */
     {
 						RenameObject *new;
 
@@ -1655,11 +1662,11 @@ yyreduce:
 
 						config_add_rename(new);
 					}
-#line 1659 "y.tab.c" /* yacc.c:1646  */
+#line 1666 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 26:
-#line 238 "parser.y" /* yacc.c:1646  */
+#line 238 "parser.y" /* yacc.c:1652  */
     {
 						RenameObject *new;
 
@@ -1671,11 +1678,11 @@ yyreduce:
 
 						config_add_rename(new);
 					}
-#line 1675 "y.tab.c" /* yacc.c:1646  */
+#line 1682 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 27:
-#line 250 "parser.y" /* yacc.c:1646  */
+#line 250 "parser.y" /* yacc.c:1652  */
     {
 						RenameObject *new;
 
@@ -1689,11 +1696,11 @@ yyreduce:
 
 						config_add_rename(new);
 					}
-#line 1693 "y.tab.c" /* yacc.c:1646  */
+#line 1700 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 28:
-#line 266 "parser.y" /* yacc.c:1646  */
+#line 266 "parser.y" /* yacc.c:1652  */
     {
 						ProcessingCommand	  **pptr;
 
@@ -1705,11 +1712,11 @@ yyreduce:
 						(*pptr)->command = (yyvsp[-1].str);
 						(*pptr)->next = NULL;
 					}
-#line 1709 "y.tab.c" /* yacc.c:1646  */
+#line 1716 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 29:
-#line 280 "parser.y" /* yacc.c:1646  */
+#line 280 "parser.y" /* yacc.c:1652  */
     {
 						ProcessingCommand	  **pptr;
 
@@ -1721,11 +1728,11 @@ yyreduce:
 						(*pptr)->command = (yyvsp[-1].str);
 						(*pptr)->next = NULL;
 					}
-#line 1725 "y.tab.c" /* yacc.c:1646  */
+#line 1732 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 30:
-#line 294 "parser.y" /* yacc.c:1646  */
+#line 294 "parser.y" /* yacc.c:1652  */
     {
 						ProcessingCommand	  **pptr;
 
@@ -1737,30 +1744,30 @@ yyreduce:
 						(*pptr)->command = (yyvsp[-1].str);
 						(*pptr)->next = NULL;
 					}
-#line 1741 "y.tab.c" /* yacc.c:1646  */
+#line 1748 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 33:
-#line 325 "parser.y" /* yacc.c:1646  */
+#line 325 "parser.y" /* yacc.c:1652  */
     {
 						if (process_simple_sql(
 							"set session_replication_role to replica;") < 0)
 							YYABORT;
 					}
-#line 1751 "y.tab.c" /* yacc.c:1646  */
+#line 1758 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 34:
-#line 333 "parser.y" /* yacc.c:1646  */
+#line 333 "parser.y" /* yacc.c:1652  */
     {
 						if (process_start_transaction("start transaction;") < 0)
 							YYABORT;
 					}
-#line 1760 "y.tab.c" /* yacc.c:1646  */
+#line 1767 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 35:
-#line 340 "parser.y" /* yacc.c:1646  */
+#line 340 "parser.y" /* yacc.c:1652  */
     {
 						SlonDString	ds;
 						int			rc;
@@ -1793,11 +1800,11 @@ yyreduce:
 						else
 							dstring_free(&ds);
 					}
-#line 1797 "y.tab.c" /* yacc.c:1646  */
+#line 1804 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 36:
-#line 374 "parser.y" /* yacc.c:1646  */
+#line 374 "parser.y" /* yacc.c:1652  */
     {
 						char   *ret;
 						size_t toklen=yyget_leng();
@@ -1807,20 +1814,20 @@ yyreduce:
 
 						(yyval.str) = ret;
 					}
-#line 1811 "y.tab.c" /* yacc.c:1646  */
+#line 1818 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 54:
-#line 407 "parser.y" /* yacc.c:1646  */
+#line 407 "parser.y" /* yacc.c:1652  */
     {
 						if (process_end_transaction("commit;") < 0)
 							YYABORT;
 					}
-#line 1820 "y.tab.c" /* yacc.c:1646  */
+#line 1827 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 55:
-#line 414 "parser.y" /* yacc.c:1646  */
+#line 414 "parser.y" /* yacc.c:1652  */
     {
 						InsertStmt	stmt;
 						AttElem	   *nelem;
@@ -1859,11 +1866,11 @@ yyreduce:
 						if (rc < 0)
 							YYABORT;
 					}
-#line 1863 "y.tab.c" /* yacc.c:1646  */
+#line 1870 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 56:
-#line 455 "parser.y" /* yacc.c:1646  */
+#line 455 "parser.y" /* yacc.c:1652  */
     {
 						AttElemList	   *new;
 						new = (AttElemList *)malloc(sizeof(AttElemList));
@@ -1877,11 +1884,11 @@ yyreduce:
 
 						(yyval.att_elem_list) = new;
 					}
-#line 1881 "y.tab.c" /* yacc.c:1646  */
+#line 1888 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 57:
-#line 469 "parser.y" /* yacc.c:1646  */
+#line 469 "parser.y" /* yacc.c:1652  */
     {
 						AttElem		   *new;
 						new = (AttElem *)malloc(sizeof(AttElem));
@@ -1895,11 +1902,11 @@ yyreduce:
 
 						(yyval.att_elem_list) = (yyvsp[-2].att_elem_list);
 					}
-#line 1899 "y.tab.c" /* yacc.c:1646  */
+#line 1906 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 58:
-#line 485 "parser.y" /* yacc.c:1646  */
+#line 485 "parser.y" /* yacc.c:1652  */
     {
 						UpdateStmt		stmt;
 						AttElem		   *elem;
@@ -1937,11 +1944,11 @@ yyreduce:
 						if (rc < 0)
 							YYABORT;
 					}
-#line 1941 "y.tab.c" /* yacc.c:1646  */
+#line 1948 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 59:
-#line 525 "parser.y" /* yacc.c:1646  */
+#line 525 "parser.y" /* yacc.c:1652  */
     {
 						AttElemList	   *new;
 						new = (AttElemList *)malloc(sizeof(AttElemList));
@@ -1951,22 +1958,22 @@ yyreduce:
 
 						(yyval.att_elem_list) = new;
 					}
-#line 1955 "y.tab.c" /* yacc.c:1646  */
+#line 1962 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 60:
-#line 535 "parser.y" /* yacc.c:1646  */
+#line 535 "parser.y" /* yacc.c:1652  */
     { 
 						(yyvsp[-2].att_elem_list)->list_tail->next = (yyvsp[0].att_elem);
 						(yyvsp[-2].att_elem_list)->list_tail = (yyvsp[0].att_elem);
 
 						(yyval.att_elem_list) = (yyvsp[-2].att_elem_list);
 					}
-#line 1966 "y.tab.c" /* yacc.c:1646  */
+#line 1973 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 61:
-#line 543 "parser.y" /* yacc.c:1646  */
+#line 543 "parser.y" /* yacc.c:1652  */
     {
 						DeleteStmt		stmt;
 						AttElem		   *elem;
@@ -1998,43 +2005,43 @@ yyreduce:
 						if (rc < 0)
 							YYABORT;
 					}
-#line 2002 "y.tab.c" /* yacc.c:1646  */
+#line 2009 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 62:
-#line 577 "parser.y" /* yacc.c:1646  */
+#line 577 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.ival) = 1;
 					}
-#line 2010 "y.tab.c" /* yacc.c:1646  */
+#line 2017 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 63:
-#line 581 "parser.y" /* yacc.c:1646  */
+#line 581 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.ival) = 0;
 					}
-#line 2018 "y.tab.c" /* yacc.c:1646  */
+#line 2025 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 64:
-#line 587 "parser.y" /* yacc.c:1646  */
+#line 587 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.att_elem_list) = (yyvsp[0].att_elem_list);
 					}
-#line 2026 "y.tab.c" /* yacc.c:1646  */
+#line 2033 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 65:
-#line 591 "parser.y" /* yacc.c:1646  */
+#line 591 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.att_elem_list) = NULL;
 					}
-#line 2034 "y.tab.c" /* yacc.c:1646  */
+#line 2041 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 66:
-#line 597 "parser.y" /* yacc.c:1646  */
+#line 597 "parser.y" /* yacc.c:1652  */
     {
 						
 						TruncateStmt stmt;
@@ -2043,11 +2050,11 @@ yyreduce:
 						process_truncate(&stmt);
 
 					}
-#line 2047 "y.tab.c" /* yacc.c:1646  */
+#line 2054 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 67:
-#line 607 "parser.y" /* yacc.c:1646  */
+#line 607 "parser.y" /* yacc.c:1652  */
     {
 						CopyStmt		stmt;
 						AttElem		   *elem;
@@ -2076,11 +2083,11 @@ yyreduce:
 						if (rc < 0)
 							YYABORT;
 					}
-#line 2080 "y.tab.c" /* yacc.c:1646  */
+#line 2087 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 68:
-#line 638 "parser.y" /* yacc.c:1646  */
+#line 638 "parser.y" /* yacc.c:1652  */
     {
 						int rc;
 
@@ -2090,11 +2097,11 @@ yyreduce:
 						if (rc < 0)
 							YYABORT;
 					}
-#line 2094 "y.tab.c" /* yacc.c:1646  */
+#line 2101 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 69:
-#line 648 "parser.y" /* yacc.c:1646  */
+#line 648 "parser.y" /* yacc.c:1652  */
     {
 						int rc;
 
@@ -2107,11 +2114,11 @@ yyreduce:
 						if (rc < 0)
 							YYABORT;
 					}
-#line 2111 "y.tab.c" /* yacc.c:1646  */
+#line 2118 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 70:
-#line 663 "parser.y" /* yacc.c:1646  */
+#line 663 "parser.y" /* yacc.c:1652  */
     {
 						SlonDString	*new;
 
@@ -2122,47 +2129,47 @@ yyreduce:
 
 						(yyval.dstring) = new;
 					}
-#line 2126 "y.tab.c" /* yacc.c:1646  */
+#line 2133 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 71:
-#line 674 "parser.y" /* yacc.c:1646  */
+#line 674 "parser.y" /* yacc.c:1652  */
     {
 						dstring_append((yyvsp[-1].dstring), (yyvsp[0].str));
 						free((yyvsp[0].str));
 
 						(yyval.dstring) = (yyvsp[-1].dstring);
 					}
-#line 2137 "y.tab.c" /* yacc.c:1646  */
+#line 2144 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 72:
-#line 683 "parser.y" /* yacc.c:1646  */
+#line 683 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.str) = strdup(yychunk);
 					}
-#line 2145 "y.tab.c" /* yacc.c:1646  */
+#line 2152 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 73:
-#line 689 "parser.y" /* yacc.c:1646  */
+#line 689 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.str) = strdup(yychunk);
 					}
-#line 2153 "y.tab.c" /* yacc.c:1646  */
+#line 2160 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 74:
-#line 695 "parser.y" /* yacc.c:1646  */
+#line 695 "parser.y" /* yacc.c:1652  */
     {
 						if (process_copyend() < 0)
 							YYABORT;
 					}
-#line 2162 "y.tab.c" /* yacc.c:1646  */
+#line 2169 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 75:
-#line 702 "parser.y" /* yacc.c:1646  */
+#line 702 "parser.y" /* yacc.c:1652  */
     {
 						AttElemList	   *new;
 						new = (AttElemList *)malloc(sizeof(AttElemList));
@@ -2176,11 +2183,11 @@ yyreduce:
 
 						(yyval.att_elem_list) = new;
 					}
-#line 2180 "y.tab.c" /* yacc.c:1646  */
+#line 2187 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 76:
-#line 716 "parser.y" /* yacc.c:1646  */
+#line 716 "parser.y" /* yacc.c:1652  */
     {
 						AttElem		   *new;
 						new = (AttElem *)malloc(sizeof(AttElem));
@@ -2194,11 +2201,11 @@ yyreduce:
 
 						(yyval.att_elem_list) = (yyvsp[-2].att_elem_list);
 					}
-#line 2198 "y.tab.c" /* yacc.c:1646  */
+#line 2205 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 77:
-#line 732 "parser.y" /* yacc.c:1646  */
+#line 732 "parser.y" /* yacc.c:1652  */
     {
 						AttElemList	   *new;
 						new = (AttElemList *)malloc(sizeof(AttElemList));
@@ -2208,22 +2215,22 @@ yyreduce:
 
 						(yyval.att_elem_list) = new;
 					}
-#line 2212 "y.tab.c" /* yacc.c:1646  */
+#line 2219 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 78:
-#line 742 "parser.y" /* yacc.c:1646  */
+#line 742 "parser.y" /* yacc.c:1652  */
     {
 						(yyvsp[-2].att_elem_list)->list_tail->next = (yyvsp[0].att_elem);
 						(yyvsp[-2].att_elem_list)->list_tail = (yyvsp[0].att_elem);
 
 						(yyval.att_elem_list) = (yyvsp[-2].att_elem_list);
 					}
-#line 2223 "y.tab.c" /* yacc.c:1646  */
+#line 2230 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 79:
-#line 751 "parser.y" /* yacc.c:1646  */
+#line 751 "parser.y" /* yacc.c:1652  */
     {
 						AttElem	   *new = (AttElem *)malloc(sizeof(AttElem));
 
@@ -2233,11 +2240,11 @@ yyreduce:
 
 						(yyval.att_elem) = new;
 					}
-#line 2237 "y.tab.c" /* yacc.c:1646  */
+#line 2244 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 80:
-#line 763 "parser.y" /* yacc.c:1646  */
+#line 763 "parser.y" /* yacc.c:1652  */
     {
 						SlonDString	ds;
 						char	   *namespace;
@@ -2264,11 +2271,11 @@ yyreduce:
 							free((yyvsp[-1].str));
 						}
 					}
-#line 2268 "y.tab.c" /* yacc.c:1646  */
+#line 2275 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 81:
-#line 792 "parser.y" /* yacc.c:1646  */
+#line 792 "parser.y" /* yacc.c:1652  */
     {
 						SlonDString	ds;
 						char	   *namespace;
@@ -2295,11 +2302,11 @@ yyreduce:
 							free((yyvsp[-1].str));
 						}
 					}
-#line 2299 "y.tab.c" /* yacc.c:1646  */
+#line 2306 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 82:
-#line 821 "parser.y" /* yacc.c:1646  */
+#line 821 "parser.y" /* yacc.c:1652  */
     {
 						SlonDString	ds;
 						dstring_init(&ds);
@@ -2315,11 +2322,11 @@ yyreduce:
 						else
 							dstring_free(&ds);
 					}
-#line 2319 "y.tab.c" /* yacc.c:1646  */
+#line 2326 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 83:
-#line 838 "parser.y" /* yacc.c:1646  */
+#line 838 "parser.y" /* yacc.c:1652  */
     {
 						char   *ret;
 						size_t toklen = yyget_leng();
@@ -2329,11 +2336,11 @@ yyreduce:
 
 						(yyval.str) = ret;
 					}
-#line 2333 "y.tab.c" /* yacc.c:1646  */
+#line 2340 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 84:
-#line 850 "parser.y" /* yacc.c:1646  */
+#line 850 "parser.y" /* yacc.c:1652  */
     {
 						SlonDString	ds;
 						dstring_init(&ds);
@@ -2350,11 +2357,11 @@ yyreduce:
 						else
 							dstring_free(&ds);
 					}
-#line 2354 "y.tab.c" /* yacc.c:1646  */
+#line 2361 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 85:
-#line 868 "parser.y" /* yacc.c:1646  */
+#line 868 "parser.y" /* yacc.c:1652  */
     {
 						char   *ret;
 						size_t toklen= yyget_leng();
@@ -2364,11 +2371,11 @@ yyreduce:
 
 						(yyval.str) = ret;
 					}
-#line 2368 "y.tab.c" /* yacc.c:1646  */
+#line 2375 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 86:
-#line 880 "parser.y" /* yacc.c:1646  */
+#line 880 "parser.y" /* yacc.c:1652  */
     {
 						SlonDString	ds;
 						dstring_init(&ds);
@@ -2386,11 +2393,11 @@ yyreduce:
 						else
 							dstring_free(&ds);
 					}
-#line 2390 "y.tab.c" /* yacc.c:1646  */
+#line 2397 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 87:
-#line 899 "parser.y" /* yacc.c:1646  */
+#line 899 "parser.y" /* yacc.c:1652  */
     {
 						char   *ret;
 						size_t toklen = yyget_leng();
@@ -2400,11 +2407,11 @@ yyreduce:
 
 						(yyval.str) = ret;
 					}
-#line 2404 "y.tab.c" /* yacc.c:1646  */
+#line 2411 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 88:
-#line 911 "parser.y" /* yacc.c:1646  */
+#line 911 "parser.y" /* yacc.c:1652  */
     {
 						SlonDString	ds;
 						int			c;
@@ -2450,11 +2457,11 @@ yyreduce:
 
 						YYACCEPT;
 					}
-#line 2454 "y.tab.c" /* yacc.c:1646  */
+#line 2461 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 91:
-#line 963 "parser.y" /* yacc.c:1646  */
+#line 963 "parser.y" /* yacc.c:1652  */
     {
 						char   *str;
 						size_t toklen = yyget_leng();
@@ -2470,19 +2477,19 @@ yyreduce:
 						else
 							free(str);
 					}
-#line 2474 "y.tab.c" /* yacc.c:1646  */
+#line 2481 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 92:
-#line 981 "parser.y" /* yacc.c:1646  */
+#line 981 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.ival) = strtol(yytext, NULL, 10);
 					}
-#line 2482 "y.tab.c" /* yacc.c:1646  */
+#line 2489 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 93:
-#line 987 "parser.y" /* yacc.c:1646  */
+#line 987 "parser.y" /* yacc.c:1652  */
     {
 						char   *ret;
 						size_t toklen = yyget_leng();
@@ -2492,11 +2499,11 @@ yyreduce:
 
 						(yyval.str) = ret;
 					}
-#line 2496 "y.tab.c" /* yacc.c:1646  */
+#line 2503 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 94:
-#line 997 "parser.y" /* yacc.c:1646  */
+#line 997 "parser.y" /* yacc.c:1652  */
     {
 						char   *ret;
 						size_t toklen = yyget_leng();
@@ -2506,19 +2513,19 @@ yyreduce:
 
 						(yyval.str) = ret;
 					}
-#line 2510 "y.tab.c" /* yacc.c:1646  */
+#line 2517 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 128:
-#line 1043 "parser.y" /* yacc.c:1646  */
+#line 1043 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.str) = (yyvsp[0].str);
 					}
-#line 2518 "y.tab.c" /* yacc.c:1646  */
+#line 2525 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 129:
-#line 1047 "parser.y" /* yacc.c:1646  */
+#line 1047 "parser.y" /* yacc.c:1652  */
     {
 						char   *ret;
 
@@ -2531,19 +2538,19 @@ yyreduce:
 						
 						(yyval.str) = ret;
 					}
-#line 2535 "y.tab.c" /* yacc.c:1646  */
+#line 2542 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 130:
-#line 1060 "parser.y" /* yacc.c:1646  */
+#line 1060 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.str) = NULL;
 					}
-#line 2543 "y.tab.c" /* yacc.c:1646  */
+#line 2550 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 131:
-#line 1066 "parser.y" /* yacc.c:1646  */
+#line 1066 "parser.y" /* yacc.c:1652  */
     {
 						SlonDString	   *dsp = (SlonDString *)malloc(sizeof(SlonDString));
 
@@ -2553,38 +2560,38 @@ yyreduce:
 
 						(yyval.dstring) = dsp;
 					}
-#line 2557 "y.tab.c" /* yacc.c:1646  */
+#line 2564 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 132:
-#line 1076 "parser.y" /* yacc.c:1646  */
+#line 1076 "parser.y" /* yacc.c:1652  */
     {
 						dstring_append((yyvsp[-1].dstring), (yyvsp[0].str));
 						free((yyvsp[0].str));
 
 						(yyval.dstring) = (yyvsp[-1].dstring);
 					}
-#line 2568 "y.tab.c" /* yacc.c:1646  */
+#line 2575 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 133:
-#line 1085 "parser.y" /* yacc.c:1646  */
+#line 1085 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.str) = strdup(yychunk);
 					}
-#line 2576 "y.tab.c" /* yacc.c:1646  */
+#line 2583 "y.tab.c" /* yacc.c:1652  */
     break;
 
   case 134:
-#line 1090 "parser.y" /* yacc.c:1646  */
+#line 1090 "parser.y" /* yacc.c:1652  */
     {
 						(yyval.str) = strdup(yychunk);
 					}
-#line 2584 "y.tab.c" /* yacc.c:1646  */
+#line 2591 "y.tab.c" /* yacc.c:1652  */
     break;
 
 
-#line 2588 "y.tab.c" /* yacc.c:1646  */
+#line 2595 "y.tab.c" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2609,14 +2616,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -2699,12 +2705,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -2766,6 +2770,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -2773,6 +2778,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -2783,6 +2789,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -2812,7 +2822,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 1094 "parser.y" /* yacc.c:1906  */
+#line 1094 "parser.y" /* yacc.c:1918  */
 
 
 
