@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: poll_cluster.sh,v 1.4 2007-12-11 20:32:50 cbbrowne Exp $
+# 
 
 mktmp=$1
 cluster=$2
@@ -34,7 +34,7 @@ fi
 if [ -n "${cluster}" ]; then
   sleep 15
   SQL="select count(*) from \"_${cluster}\".sl_log_1 l 
-where not(txid_visible_in_snapshot(l.log_txid, (select ev_snapshot from \"_${cluster}\".sl_event where ev_timestamp = (select max(ev_timestamp) from \"_${cluster}\".sl_event))));"
+where not(txid_visible_in_snapshot(l.log_txid, (select ev_snapshot from \"_${cluster}\".sl_event where ev_timestamp = (select max(ev_timestamp) from \"_${cluster}\".sl_event) limit 1)));"
   SQL2="SELECT max(st_lag_num_events) FROM \"_${cluster}\".sl_status"
   while : ; do
     lag=`${pgbindir}/psql -q -A -t -c "${SQL}" ${conninfo} 2>>$mktmp/poll.log | sed -e '/^$/d'`
