@@ -70,6 +70,7 @@ do_initdata()
   eval user=\$USER${originnode}
   eval port=\$PORT${originnode}
   # generate_initdata  - # No initial data!
+  launch_poll
   status "loading data"
   #$pgbindir/psql -h $host -p $port -d $db -U $user < $mktmp/generate.data 1> $mktmp/initdata.log 2> $mktmp/initdata.log
   if [ $? -ne 0 ]; then
@@ -78,9 +79,6 @@ do_initdata()
   wait_for_catchup
   status "done"
 
-  $pgbindir/psql -h $host -p $port -d $db -U $user -c "insert into pg_catalog.pg_autovacuum (vacrelid, enabled, vac_base_thresh, vac_scale_factor, anl_base_thresh, anl_scale_factor, vac_cost_delay, vac_cost_limit, freeze_min_age, freeze_max_age) (select oid, 'f', 0, 0, 0, 0, 0,0,0,0 from pg_catalog.pg_class where relnamespace = (select oid from pg_namespace where nsp_name = '_${CLUSTER1}') and relname = 'sl_seqlog');" 1> $mktmp/suppressautovac.log 2> $mktmp/suppressautovac.log
-  status "make sure there is at least one table being vacuumed by Slony-I"
-
   more_data
   wait_for_catchup
   status "done"
